apply_patch

Function apply_patch 

pub fn apply_patch(
    text: &mut String,
    current_revision: u64,
    patch: &SourcePatch,
) -> Result<PatchResult, PatchError>
Validates and applies patch to text, which must be at revision current_revision. On success the caller increments the document revision and triggers a full reparse.