pub struct SourcePatch {
pub base_revision: u64,
pub range: ByteRange,
pub replacement: String,
pub origin: PatchOrigin,
}Expand description
A Rust-approved mutation of a byte range in canonical text (RFC-015 7).
Fields
base_revision: u64Document revision the patch was computed against.
range: ByteRangereplacement: Stringorigin: PatchOriginTrait Implementations
Sourceimpl Clone for SourcePatch
impl Clone for SourcePatch
Sourcefn clone(&self) -> SourcePatch
fn clone(&self) -> SourcePatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourcePatch
impl Debug for SourcePatch
Sourceimpl<'de> Deserialize<'de> for SourcePatch
impl<'de> Deserialize<'de> for SourcePatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SourcePatch
Sourceimpl PartialEq for SourcePatch
impl PartialEq for SourcePatch
Sourcefn eq(&self, other: &SourcePatch) -> bool
fn eq(&self, other: &SourcePatch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SourcePatch
impl Serialize for SourcePatch
impl StructuralPartialEq for SourcePatch